==> nysol-0.3.1.tar.gz: nysol-0.3.1/src/mod/kgcut.h <==
/* ////////// LICENSE INFO ////////////////////

 * Copyright (C) 2013 by NYSOL CORPORATION
 *
 * Unless you have received this program directly from NYSOL pursuant
 * to the terms of a commercial license agreement with NYSOL, then
 * this program is licensed to you under the terms of the GNU Affero General
 * Public License (AGPL) as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF 
 * NON-INFRINGEMENT, MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Please refer to the AGPL (http://www.gnu.org/licenses/agpl-3.0.txt)
 * for more details.

 ////////// LICENSE INFO ////////////////////*/
// =============================================================================
// kgcut.h 項目の選択クラス
// =============================================================================
#pragma once
#include <kgmod.h>
#include <kgError.h>
#include <kgArgFld.h>
#include <kgCSV.h>
#include <kgCSVout.h>

using namespace kglib;

namespace kgmod { ////////////////////////////////////////////// start namespace


class kgCut : public kgMod {

	// 引数
	kgArgFld _fField;  // f=
	kgCSVfld _iFile;   // i=
	kgCSVout _oFile;   // o=
	bool     _reverse; // -r

	// 引数セット
	void setArgs(void);
	void setArgs(int inum,int *i,int onum, int* o);

	// CSV項目名出力
	void writeFldName(const vector<int>& fld ,bool reverse) throw(kgError);

	int runMain(void);
	void setArgsMain(void);	

public:

	static const char * _ipara[];
	static const char * _opara[];

	// コンストラクタ
	kgCut(void);
	~kgCut(void){}

	// 処理行数取得メソッド
	size_t iRecNo(void) const { return _iFile.recNo(); }
	size_t oRecNo(void) const { return _oFile.recNo(); }


	//実行メソッド
	int run(void);
	int run(int inum,int *i_p,int onum, int* o_p ,string & str);

	void runErrEnd(void){
		_iFile.close();
		_oFile.forceclose();
		
	}


};


}

==> nysol-0.3.13.tar.gz: nysol-0.3.13/src/mod/kgcut.h <==
/* ////////// LICENSE INFO ////////////////////

 * Copyright (C) 2013 by NYSOL CORPORATION
 *
 * Unless you have received this program directly from NYSOL pursuant
 * to the terms of a commercial license agreement with NYSOL, then
 * this program is licensed to you under the terms of the GNU Affero General
 * Public License (AGPL) as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF 
 * NON-INFRINGEMENT, MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Please refer to the AGPL (http://www.gnu.org/licenses/agpl-3.0.txt)
 * for more details.

 ////////// LICENSE INFO ////////////////////*/
// =============================================================================
// kgcut.h 項目の選択クラス
// =============================================================================
#pragma once
#include <kgmod.h>
#include <kgError.h>
#include <kgArgFld.h>
#include <kgCSV.h>
#include <kgCSVout.h>

using namespace kglib;

namespace kgmod { ////////////////////////////////////////////// start namespace


class kgCut : public kgMod {

	// 引数
	kgArgFld _fField;  // f=
	kgCSVfld _iFile;   // i=
	kgCSVout _oFile;   // o=
	bool     _reverse; // -r

	// 引数セット
	void setArgs(void);
	void setArgs(int inum,int *i,int onum, int* o);

	// CSV項目名出力
	void writeFldName(const vector<int>& fld ,bool reverse);

	int runMain(void);
	void setArgsMain(void);	

public:

	static const char * _ipara[];
	static const char * _opara[];

	// コンストラクタ
	kgCut(void);
	~kgCut(void){}

	// 処理行数取得メソッド
	size_t iRecNo(void) const { return _iFile.recNo(); }
	size_t oRecNo(void) const { return _oFile.recNo(); }


	//実行メソッド
	int run(void);
	int run(int inum,int *i_p,int onum, int* o_p ,string & str);

	void runErrEnd(void){
		_iFile.close();
		_oFile.forceclose();
		
	}


};


}
